View source: R/readGENEActiv.R
| readGENEActiv | R Documentation |
R function wrapper around GENEActivReader to read binary files as produced by the GENEActiv accelerometer by ActivInsights Ltd https://activinsights.com/
readGENEActiv(filename, start = 0L, end = 0L, progress_bar = FALSE,
desiredtz = "", configtz = NULL)
filename |
filename (required) |
start |
start page for reading data |
end |
end page for reading data |
progress_bar |
Boolean |
desiredtz |
Character, timezone database name of the timezone where the accelerometer was worn. |
configtz |
Character, timezone database name of the timezone where the accelerometer was configured. Leave NULL if equal to timezone where experiment took place. |
If only start page is defined then all data is read beyond
start until the end of the file is reached.
GENEActiv light measurements are calibrated according to the device model. For GENEActiv 1.1, the existing light calibration is applied. For GENEActiv 1.2 and above, an additional correction is applied to account for the light sensor's non-linear scaling with graded resolution. This provides greater accuracy at low light levels while supporting a higher range. This correction was provided by ActivInsights Ltd, the manufacturer of GENEActiv devices.
header:
serial_number |
Device serial number as extracted from file header |
firmware |
Firmware version |
tzone |
Time zone as extracted from file header |
ReadOK |
see GENEActivReader |
SampleRate |
matrix with battery voltage and corresponding timestamps |
ReadErrors |
matrix with battery voltage and corresponding timestamps |
numBlocksTotal |
matrix with battery voltage and corresponding timestamps |
StartTime |
Start time as extracted from file header |
data.out:
time |
Unix time in seconds with decimal places for miliseconds |
x |
see GENEActivReader |
y |
see GENEActivReader |
z |
see GENEActivReader |
light |
Ligth values express in lux units |
temperature |
Temperature in Celsius |
Patrick Bos <egpbos@gmail.com> Vincent T van Hees <v.vanhees@accelting.com>
binfile = system.file("testfiles/GENEActiv_testfile.bin", package = "GGIRread")[1]
rdata = readGENEActiv(filename = binfile, start = 1, end = 1, desiredtz = "Europe/London")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.